################################################
# Analyses of the delcine the of Rana latastei #
# Rana latastei in the Monza Park (Italy)
################################################

# Set here your working directory
setwd("...")

library(brms)
library(INLA)

# Data table
tab <- read.delim("Rana_latastei_Monza_Park.txt")

## 1) Model the changes in abundance the period 2000 - 2019

# Remove 2022 and 2023 to estimate the trend of abundance before the disappearence of the species from the study area
tab2 <- tab[!tab$Year%in%c(2022,2023),]

# Run the model of abundance changes in the period 2000 - 2019
abundance_model <- brm(N_eggs ~ Year_centr + (1|Site), data = tab2, family=negbinomial(), 
                   chains = 3, cores = 3, iter = 4000, warmup = 1000, thin = 3)
# See the results
summary(abundance_model)

## 2) Model the factors related to presence/absence of egg clutches over the entire period (2000 - 2023)

# Define factorial variables and standardize continuos variables to allow comparison of effect sizes
tab$Procambarus_clarkii <- as.factor(tab$Procambarus_clarkii)
tab$Water_management <- as.factor(tab$Water_management)
tab$Temperature <- (tab$Temperature-mean(tab$Temperature))/sd(tab$Temperature)
tab$Precipitation <- (tab$Precipitation-mean(tab$Precipitation))/sd(tab$Precipitation)

# Model formula
formula = PA ~ Procambarus_clarkii + Water_management + Temperature + Precipitation +
  f(Year, model="ar1") + f(Site, model="iid")

# Run the INLA model
result = inla(formula, family = "binomial", quantiles=c(0.025,0.05,0.1,0.5,0.9,0.95,0.975),
              data = tab, control.compute = list(dic = TRUE, waic = TRUE, config = TRUE))
# See the results
summary(result)
